==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.metrics.dropwizard/src/com/openexchange/metrics/dropwizard/impl/registerers/GaugeMetricRegisterer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.metrics.dropwizard.impl.registerers;

import com.codahale.metrics.Gauge;
import com.codahale.metrics.MetricRegistry;
import com.openexchange.metrics.MetricDescriptor;
import com.openexchange.metrics.MetricRegisterer;
import com.openexchange.metrics.dropwizard.types.DropwizardGauge;
import com.openexchange.metrics.types.Metric;

/**
 * {@link GaugeMetricRegisterer}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class GaugeMetricRegisterer implements MetricRegisterer {

    private MetricRegistry registry;

    /**
     * Initialises a new {@link GaugeMetricRegisterer}.
     */
    public GaugeMetricRegisterer(MetricRegistry registry) {
        super();
        this.registry = registry;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.metrics.MetricRegisterer#register(com.openexchange.metrics.MetricDescriptor)
     */
    @Override
    @SuppressWarnings({ "unchecked", "rawtypes" })
    public Metric register(final MetricDescriptor descriptor) {
        return new DropwizardGauge(registry.gauge(MetricRegistry.name(descriptor.getGroup(), descriptor.getName()), new MetricRegistry.MetricSupplier<Gauge>() {

            @Override
            public Gauge<Object> newMetric() {
                return new Gauge() {

                    @Override
                    public Object getValue() {
                        return descriptor.getMetricSupplier().get();
                    }
                };
            }
        }));
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.metrics.MetricRegisterer#unregister(com.openexchange.metrics.MetricDescriptor)
     */
    @Override
    public void unregister(MetricDescriptor descriptor) {
        registry.remove(MetricRegistry.name(descriptor.getGroup(), descriptor.getName()));
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.metrics.dropwizard/src/com/openexchange/metrics/dropwizard/impl/registerers/GaugeMetricRegisterer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.metrics.dropwizard.impl.registerers;

import com.codahale.metrics.MetricRegistry;
import com.openexchange.metrics.MetricDescriptor;
import com.openexchange.metrics.MetricRegisterer;
import com.openexchange.metrics.dropwizard.types.DropwizardGauge;
import com.openexchange.metrics.types.Metric;

/**
 * {@link GaugeMetricRegisterer}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class GaugeMetricRegisterer implements MetricRegisterer {

    private MetricRegistry registry;

    /**
     * Initialises a new {@link GaugeMetricRegisterer}.
     */
    public GaugeMetricRegisterer(MetricRegistry registry) {
        super();
        this.registry = registry;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.metrics.MetricRegisterer#register(com.openexchange.metrics.MetricDescriptor)
     */
    @Override
    @SuppressWarnings("unchecked")
    public Metric register(MetricDescriptor descriptor) {
        return new DropwizardGauge(registry.gauge(MetricRegistry.name(descriptor.getGroup(), descriptor.getName()), () -> () -> descriptor.getMetricSupplier().get()));
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.metrics.MetricRegisterer#unregister(com.openexchange.metrics.MetricDescriptor)
     */
    @Override
    public void unregister(MetricDescriptor descriptor) {
        registry.remove(MetricRegistry.name(descriptor.getGroup(), descriptor.getName()));
    }

}
